@@ -35,11 +35,6 @@ from . import base
 공통 영역
 '''
 
-# logging
-# base.log_batch.warning(sys.argv[0] + ' :: ' + str(datetime.today()))
-# base.log_report.info('')
-# base.log_report.info(sys.argv[0] + ' :: ' + str(datetime.today()))
-
 #####################################
 # funtions
 #####################################
@@ -106,7 +101,7 @@ def timing_strategy(ticker, short_sma, long_sma):
         change_rate = float(pivot_tickers['Change_rate'].values) * 100
         base.log_report.info(f'##### {long_sma}일 이동평균과 {short_sma}일 이동평균: Timing Strategy 에 따라 {change_date} 일부터 비중 {change_rate} % 로 조정할 것 !!! #####')
         base.log_report.info(pivot_tickers)
-        base.log_event.info('')
+        base.log_event.info(f'{sys.argv[0]} : -------------------------->')
         base.log_event.info(f'@@ event: {ticker} / {long_sma}일 이동평균과 {short_sma}일 이동평균: Timing Strategy 에 따라 {change_date} 일부터 비중 {change_rate} % 로 조정할 것 !!! #####')
         base.log_event.info(pivot_tickers)
         result
@@ -385,7 +380,7 @@ def trend_following_strategy(ticker:str, TIMEFRAMES:list):
                 base.log_report.info(b)
             if (timeframe == '1day') and ('BUY' in b):  # 여기서 b 는 마지막 건수의 B 로, 이 마지막 b 가 'BUY' 면 OK
                 result = 'BUY'
-                base.log_event.info('')
+                base.log_event.info(f'{sys.argv[0]} : -------------------------->')
                 base.log_event.info(f'@@ event: {ticker} / trend_following_strategy 에 따라  !!! #####')
                 base.log_event.info(b)
 
