@@ -5,7 +5,8 @@ Prgram 명: technical Analysis 만들기
 Author: jeongmin Kang
 Mail: jarvisNim@gmail.com
 History
-- 20240228  Create
+- 20240228 create
+- 20240415 yahoo finance UI 개편으로 새 버전으로 변경
 '''
 import sys, os, time
 import numpy as np
@@ -24,10 +25,6 @@ from . import base
 '''
 0. 공통영역 설정
 '''
-# logging
-# base.log_batch.warning(sys.argv[0] + ' :: ' + str(datetime.today()))
-# base.log_report.info('')
-# base.log_report.info(sys.argv[0] + ' :: ' + str(datetime.today()))
 
 
 # 오실로스코프형 그래프
@@ -566,7 +563,8 @@ def get_tech_yf_fin(ticker, timeframe='Q', statement='I'):
 
     return data
 
-
+'''
+20240415 yahoo finance UI 개편으로 새 버전으로 변경 
 # yfinance 를 이용한 stastics 데이터 가져오기
 def get_tech_yf_stastics(ticker):
     headers = {
@@ -589,6 +587,39 @@ def get_tech_yf_stastics(ticker):
     df.reset_index(names=['Item'], drop=True, )
     
     return df
+'''
+# yfinance 를 이용한 stastics 데이터 가져오기
+def get_tech_yf_stastics(ticker):
+    headers = {
+        "User-Agent": "Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:105.0) Gecko/20100101 Firefox/105.0"
+    }
+    url = f"https://finance.yahoo.com/quote/{ticker}/key-statistics"
+    soup = BeautifulSoup(requests.get(url, headers=headers).content, "html5lib")
+
+    data_valuation = []
+    data_others = []
+    for i, table in enumerate(soup.select("table")):
+        print(f"table: {table}")
+        if i == 0:
+            th_row = [th.text for th in table.find_all("th")]   
+            for j, tr in enumerate(table.select("tr:has(td)")):
+                td_row = [td.text for td in tr.find_all("td")]
+                data_valuation.append(td_row)
+            try:
+                th_row[0] = 'Item'
+                df_valuation = pd.DataFrame(data=data_valuation, columns=th_row)
+            except Exception as e:
+                df_valuation = pd.DataFrame()
+                df_others = pd.DataFrame()
+        else:
+            th_row = [th.text for th in table.find_all("th")]   
+            for j, tr in enumerate(table.select("tr:has(td)")):
+                td_row = [td.text for td in tr.find_all("td")]
+                data_others.append(td_row)
+            df_others = pd.DataFrame(columns=['Item','Value'], data=data_others)
+            df_others.reset_index(names=['Item'], drop=True, )
+    
+    return df_valuation, df_others
 
 
 # yfinance 를 이용한 Analysis 데이터 가져오기
